==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/commons/bean/BeanInfoMapping.java <==
package org.itscool.commons.bean;


import java.util.HashMap;

/**
 * BeanInfoMappingNX̓AvP[VNɏݒt@C
 * IuWFNg̐ǂݍ݁AێNXłB<BR>
 * BeanInfoMappingCX^X͏ݒt@C̈beanvf
 * ɑΉ܂B<BR>
 * <BR>
 *yݒt@C̐ݒBeanInfoMappingNX̃vpeBɑΉ鍀ځz<BR>
 * id   F Bean̘_<BR>
 * type F Bean̕<BR>
 * singleton F BeanVOg̏ꍇtrueZbg܂B<BR>
 *  Beanpublic statci Bean getInstance()\bh`Ă
 * Kv܂
 *<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2005/08/20
*/
public class BeanInfoMapping{
    /**
     * <code>path</code>
     */
    private String id;
    /**
     * <code>type</code>
     */
    private String type;
    
    private String value;
    
    private boolean singleton;
    
    /**
     * <code>forwards</code>
     */
    private HashMap properties = null;
    /**
     * BeanInfoMappings܂
     * @param id Bean̘_
     * @param type Bean̕
     */
    public BeanInfoMapping(String id, String type ){
        this.id = id;
        this.type = type;
        this.singleton = false;
    }
    
    /**
     * Bean̘_擾܂
     * @return Bean̘_
     */
    public String getId(){
        return id;
    }
    
    /**
     * Bean̘_Zbg܂
     * @param id Bean̘_
     */
    public void setId(String id){
        this.id = id;
    }
    
    /**
     * Bean̕擾܂
     * @return Bean̕
     */
    public String getType(){
        return type;
    }
    
    /**
     * Bean̕Zbg܂
     * @param type Bean̕
     */
    public void setType(String type){
        this.type = type;
    }
    
    /**
     * BeañvpeBǉ܂
     * @param name BeañvpeB
     * @param property vpeB
     */
    public void addProperty(String name, BeanPropertyInfo property){
        if( properties == null){
            properties = new HashMap();
        }
        properties.put(name, property);
    }
    
    /**
     * BeanۗLvpeB̃Xg擾܂
     * @return vpeB̃XgԂ܂
     */
    public HashMap getProperties(){
        return properties;
    }
	
    /**
     * vpeBŎw肳ꂽvpeB擾܂
     * @param name vpeB
     * @return vpeB
     */
    public BeanPropertyInfo getProperty(String name){
        return (BeanPropertyInfo)properties.get(name);
    }
    
    /**
     * VOg[h擾܂
     * @return VOg[h
     */
	public boolean getSingleton() {
		return singleton;
	}
	
	/**
	 * VOg[hZbg܂
	 * @param singleton VOg[h
	 */
	public void setSingleton(boolean singleton) {
		this.singleton = singleton;
	}

	public String getValue() {
		return value;
	}

	public void setValue(String value) {
		this.value = value;
	}
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/commons/bean/BeanInfoMapping.java <==
package org.itscool.commons.bean;


import java.util.HashMap;

/**
 * BeanInfoMappingNX̓AvP[VNɏݒt@C
 * IuWFNg̐ǂݍ݁AێNXłB<BR>
 * BeanInfoMappingCX^X͏ݒt@C̈beanvf
 * ɑΉ܂B<BR>
 * <BR>
 *yݒt@C̐ݒBeanInfoMappingNX̃vpeBɑΉ鍀ځz<BR>
 * id   F Bean̘_<BR>
 * type F Bean̕<BR>
 * singleton F BeanVOg̏ꍇtrueZbg܂B<BR>
 *  Beanpublic statci Bean getInstance()\bh`Ă
 * Kv܂
 *<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2005/08/20
*/
public class BeanInfoMapping{
    private String id;
    private String type;
    private String value;
    private boolean singleton;
    private HashMap properties = null;
    
    /**
     * BeanInfoMappings܂
     * @param id Bean̘_
     * @param type Bean̕
     */
    public BeanInfoMapping(String id, String type ){
        this.id = id;
        this.type = type;
        this.singleton = false;
    }
    
    /**
     * Bean̘_擾܂
     * @return Bean̘_
     */
    public String getId(){
        return id;
    }
    
    /**
     * Bean̘_Zbg܂
     * @param id Bean̘_
     */
    public void setId(String id){
        this.id = id;
    }
    
    /**
     * Bean̕擾܂
     * @return Bean̕
     */
    public String getType(){
        return type;
    }
    
    /**
     * Bean̕Zbg܂
     * @param type Bean̕
     */
    public void setType(String type){
        this.type = type;
    }
    
    /**
     * BeañvpeBǉ܂
     * @param name BeañvpeB
     * @param property vpeB
     */
    public void addProperty(String name, BeanPropertyInfo property){
        if( properties == null){
            properties = new HashMap();
        }
        properties.put(name, property);
    }
    
    /**
     * BeanۗLvpeB̃Xg擾܂
     * @return vpeB̃XgԂ܂
     */
    public HashMap getProperties(){
        return properties;
    }
	
    /**
     * vpeBŎw肳ꂽvpeB擾܂
     * @param name vpeB
     * @return vpeB
     */
    public BeanPropertyInfo getProperty(String name){
        return (BeanPropertyInfo)properties.get(name);
    }
    
    /**
     * VOg[h擾܂
     * @return VOg[h
     */
	public boolean getSingleton() {
		return singleton;
	}
	
	/**
	 * VOg[hZbg܂
	 * @param singleton VOg[h
	 */
	public void setSingleton(boolean singleton) {
		this.singleton = singleton;
	}
	
	/**
	 * IuWFNg̏l擾܂
	 * @return IuWFNg̏l
	 */
	public String getValue() {
		return value;
	}
	
	/**
	 * IuWFNg̏lZbg܂
	 * @param value IuWFNg̏l
	 */
	public void setValue(String value) {
		this.value = value;
	}
}
